package sgc.portal.as.as0102.persistence;
import java.util.List;

import org.apache.ibatis.annotations.Mapper;

import sgc.portal.as.as0102.dto.AS01020001USearch;
import sgc.portal.as.as0102.model.AS01020001U;
import sgc.portal.as.as0102.model.AS01020002U;
import sgc.portal.base.util.EasyHashMap;

@Mapper
public interface AS01020001UMapper {
	
	//협력업체관리 조회
	List<EasyHashMap<String, Object>> selectSmComCovendList(AS01020001USearch search);
	
	//협력업체관리팝업 조회
	EasyHashMap<String, Object> selectSmComCovendPopList(AS01020001USearch search);
	
	//협력업체 업체유형 조회
	List<EasyHashMap<String, Object>> selectSmComCovendTypePopList(AS01020001USearch search);
	
	//협력업체 담당자정보 조회
	List<EasyHashMap<String, Object>> selectSmComCovendChrgrPopList(AS01020001USearch search);
	List<EasyHashMap<String, Object>> selectSmComCovendChrgrUserIdList(AS01020001USearch search);
	
	//협력업체관리팝업
	void updateSmComCovend(AS01020001U cS01010001U);
	int selectSmComCovendCount(AS01020001U cS01010001U);
	int selectSmComCovendAflIdCount(AS01020001U cS01010001U);
	
	String selectSmComCovendId(AS01020001U cS01010001U);
	void updateSmComCovendAflId(AS01020001U cS01010001U);
	
	//협력업체 업체유형팝업d
	void insertSmComCovendType(AS01020001U cS01010001U);
	void updateSmComCovendType(AS01020001U cS01010001U);
	void deleteSmComCovendType(AS01020001U cS01010001U);
	
	int selectSmComCovendTypeCount(AS01020001U cS01010001U);
	
	int selectSmComCovendChrgrCount(AS01020002U cS01010002U);
	void updateSmComCovendChrgr(AS01020002U cS01010002U);
	
}
